==> SyFi-0.3.0.tar.gz: SyFi-0.3.0/python/tests/crouzeixraviart.py <==
#!/usr/bin/python

from swiginac import *
from SyFi import *

x = cvar.x; y = cvar.y; z = cvar.z # fetch some global variables 


class CrouzeixRaviart(StandardFE): 
  """ 
    Python implementation of the Crouzeix-Raviart element. 
    The corresponding C++ implementation is in the 
    file CrouzeixRaviart.cpp.

    Notice that cross-language inheritance works! 
    The functions (used below) 
      ex N(int i) 
      ex dof(int i) 
    and the exvectors Ns and dofs are inherited from the C++ class StandardFE. 
  """ 

  def __init__(self):  
    """ Constructor """
    StandardFE.__init__(self)

  def compute_basis_functions(self): 
    """ 
    Compute the basis functions and degrees of freedom  
    and put them in Ns and dofs, respectively. 
    """
    polspace = bernstein(1,triangle,"a")
    N = polspace.eval()[0]
    variables = polspace.eval()[1]

    for i in range(0,3): 
      line = triangle.line(i+1)
      dofi = line.integrate(toex(N)) 
      self.dofs.append(dofi)

    for i in range(0,3): 
      equations = []
      for j in range(0,3): 
        equations.append(self.dofs[j].eval() == dirac(i,j) )
      sub = lsolve(equations, variables) 
      Ni = N.subs(sub) 
      self.Ns.append(toex(Ni)); 


p0 = [0,0,0]; p1 = [1,0,0]; p2 = [0,1,0]; 

triangle = Triangle(toex(p0), toex(p1), toex(p2)) 

fe = CrouzeixRaviart()
fe.set(triangle)
fe.compute_basis_functions()
for i in range(0,fe.nbf()): 
  print "N(%d)       = "%i,   fe.N(i).eval().printc()
  print "grad(N(%d)) = "%i,   grad(fe.N(i)).eval().printc()
  print "dof(%d)     = "%i,   fe.dof(i).eval().printc()

==> SyFi-0.3.2.tar.gz: SyFi-0.3.2/python/tests/crouzeixraviart.py <==
#!/usr/bin/python

from swiginac import *
from SyFi import *

x = cvar.x; y = cvar.y; z = cvar.z # fetch some global variables 


class CrouzeixRaviart(StandardFE): 
  """ 
    Python implementation of the Crouzeix-Raviart element. 
    The corresponding C++ implementation is in the 
    file CrouzeixRaviart.cpp.

    Notice that cross-language inheritance works! 
    The functions (used below) 
      ex N(int i) 
      ex dof(int i) 
    and the exvectors Ns and dofs are inherited from the C++ class StandardFE. 
  """ 

  def __init__(self):  
    """ Constructor """
    StandardFE.__init__(self)

  def compute_basis_functions(self): 
    """ 
    Compute the basis functions and degrees of freedom  
    and put them in Ns and dofs, respectively. 
    """
    polspace = bernstein(1,triangle,"a")
    N = polspace[0]
    variables = polspace[1]

    for i in range(0,3): 
      line = triangle.line(i+1)
      dofi = line.integrate(N) 
      self.dofs.append(dofi)

    for i in range(0,3): 
      equations = []
      for j in range(0,3): 
        equations.append(relational(self.dofs[j], dirac(i,j)))
      sub = lsolve(equations, variables) 
      Ni = N.subs(sub) 
      self.Ns.append(Ni); 


p0 = [0,0,0]; p1 = [1,0,0]; p2 = [0,1,0]; 

triangle = Triangle(p0, p1, p2) 

fe = CrouzeixRaviart()
fe.set(triangle)
fe.compute_basis_functions()
for i in range(0,fe.nbf()): 
  print "N(%d)       = "%i,   fe.N(i).eval().printc()
  print "grad(N(%d)) = "%i,   grad(fe.N(i)).eval().printc()
  print "dof(%d)     = "%i,   fe.dof(i).eval().printc()
